#[repr(transparent)]pub struct Caplength(pub u8);Expand description
Capability Registers Length
Tuple Fields
0: u8Implementations
Sourceimpl Caplength
impl Caplength
Sourcepub const fn caplength(&self) -> u8
pub const fn caplength(&self) -> u8
These bits are used as an offset to add to register base to find the beginning of the Operational Register
Sourcepub const fn set_caplength(&mut self, val: u8)
pub const fn set_caplength(&mut self, val: u8)
These bits are used as an offset to add to register base to find the beginning of the Operational Register