nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Endptctrl0

Struct Endptctrl0 

#[repr(transparent)]
pub struct Endptctrl0(pub u32);
Endpoint Control0

Tuple Fields

0: u32

Implementations

Source

impl Endptctrl0

pub const fn rxs(&self) -> bool

RX Endpoint Stall - Read/Write 0 End Point OK

pub const fn set_rxs(&mut self, val: bool)

RX Endpoint Stall - Read/Write 0 End Point OK

pub const fn rxt(&self) -> u8

RX Endpoint Type - Read/Write 00 Control Endpoint0 is fixed as a Control End Point.

pub const fn set_rxt(&mut self, val: u8)

RX Endpoint Type - Read/Write 00 Control Endpoint0 is fixed as a Control End Point.

pub const fn rxe(&self) -> bool

RX Endpoint Enable 1 Enabled Endpoint0 is always enabled.

pub const fn set_rxe(&mut self, val: bool)

RX Endpoint Enable 1 Enabled Endpoint0 is always enabled.

pub const fn txs(&self) -> bool

TX Endpoint Stall - Read/Write 0 End Point OK [Default] 1 End Point Stalled Software can write a one to this bit to force the endpoint to return a STALL handshake to the Host

pub const fn set_txs(&mut self, val: bool)

TX Endpoint Stall - Read/Write 0 End Point OK [Default] 1 End Point Stalled Software can write a one to this bit to force the endpoint to return a STALL handshake to the Host

pub const fn txt(&self) -> u8

TX Endpoint Type - Read/Write 00 - Control Endpoint0 is fixed as a Control End Point.

pub const fn set_txt(&mut self, val: u8)

TX Endpoint Type - Read/Write 00 - Control Endpoint0 is fixed as a Control End Point.

pub const fn txe(&self) -> bool

TX Endpoint Enable 1 Enabled Endpoint0 is always enabled.

pub const fn set_txe(&mut self, val: bool)

TX Endpoint Enable 1 Enabled Endpoint0 is always enabled.