nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Gptimer1ctrl

Struct Gptimer1ctrl 

#[repr(transparent)]
pub struct Gptimer1ctrl(pub u32);
General Purpose Timer #1 Controller

Tuple Fields

0: u32

Implementations

Source

impl Gptimer1ctrl

pub const fn gptcnt(&self) -> u32

General Purpose Timer Counter. This field is the count value of the countdown timer.

pub const fn set_gptcnt(&mut self, val: u32)

General Purpose Timer Counter. This field is the count value of the countdown timer.

pub const fn gptmode(&self) -> Gptimer1ctrlGptmode

General Purpose Timer Mode In one shot mode, the timer will count down to zero, generate an interrupt, and stop until the counter is reset by software

pub const fn set_gptmode(&mut self, val: Gptimer1ctrlGptmode)

General Purpose Timer Mode In one shot mode, the timer will count down to zero, generate an interrupt, and stop until the counter is reset by software

pub const fn gptrst(&self) -> Gptimer1ctrlGptrst

General Purpose Timer Reset

pub const fn set_gptrst(&mut self, val: Gptimer1ctrlGptrst)

General Purpose Timer Reset

pub const fn gptrun(&self) -> Gptimer1ctrlGptrun

General Purpose Timer Run GPTCNT bits are not effected when setting or clearing this bit.

pub const fn set_gptrun(&mut self, val: Gptimer1ctrlGptrun)

General Purpose Timer Run GPTCNT bits are not effected when setting or clearing this bit.