nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Hccparams

Struct Hccparams 

#[repr(transparent)]
pub struct Hccparams(pub u32);
Host Controller Capability Parameters

Tuple Fields

0: u32

Implementations

Source

impl Hccparams

pub const fn adc(&self) -> bool

64-bit Addressing Capability This bit is set ‘0b’ in all controller core, no 64-bit addressing capability is supported

pub const fn set_adc(&mut self, val: bool)

64-bit Addressing Capability This bit is set ‘0b’ in all controller core, no 64-bit addressing capability is supported

pub const fn pfl(&self) -> bool

Programmable Frame List Flag If this bit is set to zero, then the system software must use a frame list length of 1024 elements with this host controller

pub const fn set_pfl(&mut self, val: bool)

Programmable Frame List Flag If this bit is set to zero, then the system software must use a frame list length of 1024 elements with this host controller

pub const fn asp(&self) -> bool

Asynchronous Schedule Park Capability If this bit is set to a one, then the host controller supports the park feature for high-speed queue heads in the Asynchronous Schedule

pub const fn set_asp(&mut self, val: bool)

Asynchronous Schedule Park Capability If this bit is set to a one, then the host controller supports the park feature for high-speed queue heads in the Asynchronous Schedule

pub const fn ist(&self) -> u8

Isochronous Scheduling Threshold

pub const fn set_ist(&mut self, val: u8)

Isochronous Scheduling Threshold

pub const fn eecp(&self) -> u8

EHCI Extended Capabilities Pointer

pub const fn set_eecp(&mut self, val: u8)

EHCI Extended Capabilities Pointer