#[repr(transparent)]pub struct Hciversion(pub u16);Expand description
Host Controller Interface Version
Tuple Fields
0: u16Implementations
Sourceimpl Hciversion
impl Hciversion
Sourcepub const fn hciversion(&self) -> u16
pub const fn hciversion(&self) -> u16
Host Controller Interface Version Number Default value is ‘10h’, which means EHCI rev1.0.
Sourcepub const fn set_hciversion(&mut self, val: u16)
pub const fn set_hciversion(&mut self, val: u16)
Host Controller Interface Version Number Default value is ‘10h’, which means EHCI rev1.0.