#[repr(transparent)]pub struct Hcsparams(pub u32);Expand description
Host Controller Structural Parameters
Tuple Fields
0: u32Implementations
Sourceimpl Hcsparams
impl Hcsparams
Sourcepub const fn set_n_ports(&mut self, val: u8)
pub const fn set_n_ports(&mut self, val: u8)
Number of downstream ports
Sourcepub const fn ppc(&self) -> bool
pub const fn ppc(&self) -> bool
Port Power Control This field indicates whether the host controller implementation includes port power control
Sourcepub const fn set_ppc(&mut self, val: bool)
pub const fn set_ppc(&mut self, val: bool)
Port Power Control This field indicates whether the host controller implementation includes port power control
Sourcepub const fn n_pcc(&self) -> u8
pub const fn n_pcc(&self) -> u8
Number of Ports per Companion Controller This field indicates the number of ports supported per internal Companion Controller
Sourcepub const fn set_n_pcc(&mut self, val: u8)
pub const fn set_n_pcc(&mut self, val: u8)
Number of Ports per Companion Controller This field indicates the number of ports supported per internal Companion Controller
Sourcepub const fn pi(&self) -> bool
pub const fn pi(&self) -> bool
Port Indicators (P INDICATOR) This bit indicates whether the ports support port indicator control