#[repr(transparent)]pub struct Hwhost(pub u32);Expand description
Host Hardware Parameters
Tuple Fields
0: u32Implementations
Sourceimpl Hwhost
impl Hwhost
Sourcepub const fn hc(&self) -> Hc
pub const fn hc(&self) -> Hc
Host Capable. Indicating whether host operation mode is supported or not.
Sourcepub const fn set_hc(&mut self, val: Hc)
pub const fn set_hc(&mut self, val: Hc)
Host Capable. Indicating whether host operation mode is supported or not.