nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Hwrxbuf

Struct Hwrxbuf 

#[repr(transparent)]
pub struct Hwrxbuf(pub u32);
RX Buffer Hardware Parameters

Tuple Fields

0: u32

Implementations

Source

impl Hwrxbuf

pub const fn rxburst(&self) -> u8

Default burst size for memory to RX buffer transfer

pub const fn set_rxburst(&mut self, val: u8)

Default burst size for memory to RX buffer transfer

pub const fn rxadd(&self) -> u8

Buffer total size for all receive endpoints is (2^RXADD)

pub const fn set_rxadd(&mut self, val: u8)

Buffer total size for all receive endpoints is (2^RXADD)