#[repr(transparent)]pub struct Portsc1(pub u32);Expand description
Port Status & Control
Tuple Fields
0: u32Implementations
Sourceimpl Portsc1
impl Portsc1
Sourcepub const fn set_wkdc(&mut self, val: bool)
pub const fn set_wkdc(&mut self, val: bool)
Wake on Disconnect Enable (WKDSCNNT_E) - Read/Write
Sourcepub const fn set_phcd(&mut self, val: Phcd)
pub const fn set_phcd(&mut self, val: Phcd)
PHY Low Power Suspend - Clock Disable (PLPSCD) - Read/Write
Sourcepub const fn pspd(&self) -> Pspd
pub const fn pspd(&self) -> Pspd
Port Speed - Read Only. This register field indicates the speed at which the port is operating.
Sourcepub const fn set_pspd(&mut self, val: Pspd)
pub const fn set_pspd(&mut self, val: Pspd)
Port Speed - Read Only. This register field indicates the speed at which the port is operating.
Sourcepub const fn ptw(&self) -> Ptw
pub const fn ptw(&self) -> Ptw
Parallel Transceiver Width This bit has no effect if serial interface engine is used
Sourcepub const fn set_ptw(&mut self, val: Ptw)
pub const fn set_ptw(&mut self, val: Ptw)
Parallel Transceiver Width This bit has no effect if serial interface engine is used
Sourcepub const fn sts(&self) -> bool
pub const fn sts(&self) -> bool
Serial Transceiver Select 1 Serial Interface Engine is selected 0 Parallel Interface signals is selected Serial Interface Engine can be used in combination with UTMI+/ULPI physical interface to provide FS/LS signaling instead of the parallel interface signals
Sourcepub const fn set_sts(&mut self, val: bool)
pub const fn set_sts(&mut self, val: bool)
Serial Transceiver Select 1 Serial Interface Engine is selected 0 Parallel Interface signals is selected Serial Interface Engine can be used in combination with UTMI+/ULPI physical interface to provide FS/LS signaling instead of the parallel interface signals