#[repr(transparent)]pub struct Sbuscfg(pub u32);Expand description
System Bus Config
Tuple Fields
0: u32Implementations
Sourceimpl Sbuscfg
impl Sbuscfg
Sourcepub const fn ahbbrst(&self) -> Ahbbrst
pub const fn ahbbrst(&self) -> Ahbbrst
AHB master interface Burst configuration These bits control AHB master transfer type sequence (or priority)
Sourcepub const fn set_ahbbrst(&mut self, val: Ahbbrst)
pub const fn set_ahbbrst(&mut self, val: Ahbbrst)
AHB master interface Burst configuration These bits control AHB master transfer type sequence (or priority)