Struct Usbcmd
Source #[repr(transparent)]
pub struct Usbcmd(pub u32);
Run/Stop (RS) - Read/Write
Run/Stop (RS) - Read/Write
Controller Reset (RESET) - Read/Write
Controller Reset (RESET) - Read/Write
See description at bit 15
See description at bit 15
Periodic Schedule Enable- Read/Write
Periodic Schedule Enable- Read/Write
Asynchronous Schedule Enable - Read/Write
Asynchronous Schedule Enable - Read/Write
Interrupt on Async Advance Doorbell - Read/Write
Interrupt on Async Advance Doorbell - Read/Write
Asynchronous Schedule Park Mode Count - Read/Write
Asynchronous Schedule Park Mode Count - Read/Write
Asynchronous Schedule Park Mode Enable - Read/Write
Asynchronous Schedule Park Mode Enable - Read/Write
Setup TripWire - Read/Write
Setup TripWire - Read/Write
Add dTD TripWire - Read/Write
Add dTD TripWire - Read/Write
Frame List Size - (Read/Write or Read Only)
Frame List Size - (Read/Write or Read Only)
Interrupt Threshold Control -Read/Write
Interrupt Threshold Control -Read/Write
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.