nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Usbintr

Struct Usbintr 

#[repr(transparent)]
pub struct Usbintr(pub u32);
Interrupt Enable Register

Tuple Fields

0: u32

Implementations

Source

impl Usbintr

pub const fn ue(&self) -> bool

USB Interrupt Enable When this bit is one and the UI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_ue(&mut self, val: bool)

USB Interrupt Enable When this bit is one and the UI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn uee(&self) -> bool

USB Error Interrupt Enable When this bit is one and the UEI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_uee(&mut self, val: bool)

USB Error Interrupt Enable When this bit is one and the UEI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn pce(&self) -> bool

Port Change Detect Interrupt Enable When this bit is one and the PCI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_pce(&mut self, val: bool)

Port Change Detect Interrupt Enable When this bit is one and the PCI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn fre(&self) -> bool

Frame List Rollover Interrupt Enable When this bit is one and the FRI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_fre(&mut self, val: bool)

Frame List Rollover Interrupt Enable When this bit is one and the FRI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn see(&self) -> bool

System Error Interrupt Enable When this bit is one and the SEI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_see(&mut self, val: bool)

System Error Interrupt Enable When this bit is one and the SEI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn aae(&self) -> bool

Async Advance Interrupt Enable When this bit is one and the AAI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_aae(&mut self, val: bool)

Async Advance Interrupt Enable When this bit is one and the AAI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn ure(&self) -> bool

USB Reset Interrupt Enable When this bit is one and the URI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_ure(&mut self, val: bool)

USB Reset Interrupt Enable When this bit is one and the URI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn sre(&self) -> bool

SOF Received Interrupt Enable When this bit is one and the SRI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_sre(&mut self, val: bool)

SOF Received Interrupt Enable When this bit is one and the SRI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn sle(&self) -> bool

Sleep Interrupt Enable When this bit is one and the SLI bit in n_n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_sle(&mut self, val: bool)

Sleep Interrupt Enable When this bit is one and the SLI bit in n_n_USBSTS register is a one the controller will issue an interrupt

pub const fn ulpie(&self) -> bool

ULPI Interrupt Enable When this bit is one and the UPLII bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_ulpie(&mut self, val: bool)

ULPI Interrupt Enable When this bit is one and the UPLII bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn nake(&self) -> bool

NAK Interrupt Enable When this bit is one and the NAKI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_nake(&mut self, val: bool)

NAK Interrupt Enable When this bit is one and the NAKI bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn uaie(&self) -> bool

USB Host Asynchronous Interrupt Enable When this bit is one, and the UAI bit in the n_USBSTS register is one, host controller will issue an interrupt at the next interrupt threshold

pub const fn set_uaie(&mut self, val: bool)

USB Host Asynchronous Interrupt Enable When this bit is one, and the UAI bit in the n_USBSTS register is one, host controller will issue an interrupt at the next interrupt threshold

pub const fn upie(&self) -> bool

USB Host Periodic Interrupt Enable When this bit is one, and the UPI bit in the n_USBSTS register is one, host controller will issue an interrupt at the next interrupt threshold

pub const fn set_upie(&mut self, val: bool)

USB Host Periodic Interrupt Enable When this bit is one, and the UPI bit in the n_USBSTS register is one, host controller will issue an interrupt at the next interrupt threshold

pub const fn tie0(&self) -> bool

General Purpose Timer #0 Interrupt Enable When this bit is one and the TI0 bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_tie0(&mut self, val: bool)

General Purpose Timer #0 Interrupt Enable When this bit is one and the TI0 bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn tie1(&self) -> bool

General Purpose Timer #1 Interrupt Enable When this bit is one and the TI1 bit in n_USBSTS register is a one the controller will issue an interrupt

pub const fn set_tie1(&mut self, val: bool)

General Purpose Timer #1 Interrupt Enable When this bit is one and the TI1 bit in n_USBSTS register is a one the controller will issue an interrupt