Struct Usbsts
Source #[repr(transparent)]
pub struct Usbsts(pub u32);
USB Interrupt (USBINT) - R/WC
USB Interrupt (USBINT) - R/WC
USB Error Interrupt (USBERRINT) - R/WC
USB Error Interrupt (USBERRINT) - R/WC
Port Change Detect - R/WC
Port Change Detect - R/WC
Frame List Rollover - R/WC
Frame List Rollover - R/WC
Interrupt on Async Advance - R/WC
Interrupt on Async Advance - R/WC
USB Reset Received - R/WC
USB Reset Received - R/WC
Periodic Schedule Status - Read Only
Periodic Schedule Status - Read Only
Asynchronous Schedule Status - Read Only
Asynchronous Schedule Status - Read Only
General Purpose Timer Interrupt 0(GPTINT0)–R/WC
General Purpose Timer Interrupt 0(GPTINT0)–R/WC
General Purpose Timer Interrupt 1(GPTINT1)–R/WC
General Purpose Timer Interrupt 1(GPTINT1)–R/WC
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.