#[repr(transparent)]pub struct Endptctrl0(pub u32);Expand description
Endpoint Control0
Tuple Fields
0: u32Implementations
Sourceimpl Endptctrl0
impl Endptctrl0
Sourcepub const fn rxt(&self) -> u8
pub const fn rxt(&self) -> u8
RX Endpoint Type - Read/Write 00 Control Endpoint0 is fixed as a Control End Point.
Sourcepub const fn set_rxt(&mut self, val: u8)
pub const fn set_rxt(&mut self, val: u8)
RX Endpoint Type - Read/Write 00 Control Endpoint0 is fixed as a Control End Point.
Sourcepub const fn set_rxe(&mut self, val: bool)
pub const fn set_rxe(&mut self, val: bool)
RX Endpoint Enable 1 Enabled Endpoint0 is always enabled.
Sourcepub const fn txs(&self) -> bool
pub const fn txs(&self) -> bool
TX Endpoint Stall - Read/Write 0 End Point OK [Default] 1 End Point Stalled Software can write a one to this bit to force the endpoint to return a STALL handshake to the Host
Sourcepub const fn set_txs(&mut self, val: bool)
pub const fn set_txs(&mut self, val: bool)
TX Endpoint Stall - Read/Write 0 End Point OK [Default] 1 End Point Stalled Software can write a one to this bit to force the endpoint to return a STALL handshake to the Host
Sourcepub const fn txt(&self) -> u8
pub const fn txt(&self) -> u8
TX Endpoint Type - Read/Write 00 - Control Endpoint0 is fixed as a Control End Point.