#[repr(transparent)]pub struct Gptimer1ctrl(pub u32);Expand description
General Purpose Timer #1 Controller
Tuple Fields
0: u32Implementations
Sourceimpl Gptimer1ctrl
impl Gptimer1ctrl
Sourcepub const fn gptcnt(&self) -> u32
pub const fn gptcnt(&self) -> u32
General Purpose Timer Counter. This field is the count value of the countdown timer.
Sourcepub const fn set_gptcnt(&mut self, val: u32)
pub const fn set_gptcnt(&mut self, val: u32)
General Purpose Timer Counter. This field is the count value of the countdown timer.
Sourcepub const fn gptmode(&self) -> Gptimer1ctrlGptmode
pub const fn gptmode(&self) -> Gptimer1ctrlGptmode
General Purpose Timer Mode In one shot mode, the timer will count down to zero, generate an interrupt, and stop until the counter is reset by software
Sourcepub const fn set_gptmode(&mut self, val: Gptimer1ctrlGptmode)
pub const fn set_gptmode(&mut self, val: Gptimer1ctrlGptmode)
General Purpose Timer Mode In one shot mode, the timer will count down to zero, generate an interrupt, and stop until the counter is reset by software
Sourcepub const fn gptrst(&self) -> Gptimer1ctrlGptrst
pub const fn gptrst(&self) -> Gptimer1ctrlGptrst
General Purpose Timer Reset
Sourcepub const fn set_gptrst(&mut self, val: Gptimer1ctrlGptrst)
pub const fn set_gptrst(&mut self, val: Gptimer1ctrlGptrst)
General Purpose Timer Reset
Sourcepub const fn gptrun(&self) -> Gptimer1ctrlGptrun
pub const fn gptrun(&self) -> Gptimer1ctrlGptrun
General Purpose Timer Run GPTCNT bits are not effected when setting or clearing this bit.
Sourcepub const fn set_gptrun(&mut self, val: Gptimer1ctrlGptrun)
pub const fn set_gptrun(&mut self, val: Gptimer1ctrlGptrun)
General Purpose Timer Run GPTCNT bits are not effected when setting or clearing this bit.