#[repr(transparent)]pub struct Hccparams(pub u32);Expand description
Host Controller Capability Parameters
Tuple Fields
0: u32Implementations
Sourceimpl Hccparams
impl Hccparams
Sourcepub const fn adc(&self) -> bool
pub const fn adc(&self) -> bool
64-bit Addressing Capability This bit is set ‘0b’ in all controller core, no 64-bit addressing capability is supported
Sourcepub const fn set_adc(&mut self, val: bool)
pub const fn set_adc(&mut self, val: bool)
64-bit Addressing Capability This bit is set ‘0b’ in all controller core, no 64-bit addressing capability is supported
Sourcepub const fn pfl(&self) -> bool
pub const fn pfl(&self) -> bool
Programmable Frame List Flag If this bit is set to zero, then the system software must use a frame list length of 1024 elements with this host controller
Sourcepub const fn set_pfl(&mut self, val: bool)
pub const fn set_pfl(&mut self, val: bool)
Programmable Frame List Flag If this bit is set to zero, then the system software must use a frame list length of 1024 elements with this host controller
Sourcepub const fn asp(&self) -> bool
pub const fn asp(&self) -> bool
Asynchronous Schedule Park Capability If this bit is set to a one, then the host controller supports the park feature for high-speed queue heads in the Asynchronous Schedule